/* This file is part of Mailfromd.
   Copyright (C) 2010 Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>. */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif
#include <stdlib.h>
#include <string.h>
#include <mailutils/error.h>
#include <gettext.h>

#define DEFINE_BUILTIN_MODULE
#include "builtin.h"

void
builtin_setup ()
{
	struct builtin_module *mod;
	for (mod = builtin_module; mod->name; mod++)
		if (mod->init)
			mod->init();
}

void
builtin_set_module_trace(const char *name, size_t len, int val)
{
	struct builtin_module *mod;
	
	for (mod = builtin_module; mod->name; mod++)
		if (strlen (mod->name) == len
		    && memcmp(mod->name, name, len) == 0) {
			mod->trace = val;
			return;
		}

	mu_error(gettext("no such module: %*.*s"), len, len, name);
}

void
builtin_set_all_module_trace(int val)
{
	struct builtin_module *mod;

	for (mod = builtin_module; mod->name; mod++)
		mod->trace = val;
}

int
builtin_module_trace(unsigned idx)
{
	return idx < BUILTIN_IDX_MAX && builtin_module[idx].trace;
}
